==> mapnik-4.0.0.arm64_sonoma.bottle.tar.gz: mapnik/4.0.0/lib/cmake/mapnik/mapnikTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "mapnik::json" for configuration "Release"
set_property(TARGET mapnik::json APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(mapnik::json PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libmapnikjson.a"
  )

list(APPEND _cmake_import_check_targets mapnik::json )
list(APPEND _cmake_import_check_files_for_mapnik::json "${_IMPORT_PREFIX}/lib/libmapnikjson.a" )

# Import target "mapnik::wkt" for configuration "Release"
set_property(TARGET mapnik::wkt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(mapnik::wkt PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libmapnikwkt.a"
  )

list(APPEND _cmake_import_check_targets mapnik::wkt )
list(APPEND _cmake_import_check_files_for_mapnik::wkt "${_IMPORT_PREFIX}/lib/libmapnikwkt.a" )

# Import target "mapnik::mapnik" for configuration "Release"
set_property(TARGET mapnik::mapnik APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(mapnik::mapnik PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libmapnik.4.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/libmapnik.4.0.0.dylib"
  )

list(APPEND _cmake_import_check_targets mapnik::mapnik )
list(APPEND _cmake_import_check_files_for_mapnik::mapnik "${_IMPORT_PREFIX}/lib/libmapnik.4.0.0.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mapnik-4.0.2.arm64_sonoma.bottle.tar.gz: mapnik/4.0.2/lib/cmake/mapnik/mapnikTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "mapnik::json" for configuration "Release"
set_property(TARGET mapnik::json APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(mapnik::json PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libmapnikjson.a"
  )

list(APPEND _cmake_import_check_targets mapnik::json )
list(APPEND _cmake_import_check_files_for_mapnik::json "${_IMPORT_PREFIX}/lib/libmapnikjson.a" )

# Import target "mapnik::wkt" for configuration "Release"
set_property(TARGET mapnik::wkt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(mapnik::wkt PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libmapnikwkt.a"
  )

list(APPEND _cmake_import_check_targets mapnik::wkt )
list(APPEND _cmake_import_check_files_for_mapnik::wkt "${_IMPORT_PREFIX}/lib/libmapnikwkt.a" )

# Import target "mapnik::mapnik" for configuration "Release"
set_property(TARGET mapnik::mapnik APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(mapnik::mapnik PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libmapnik.4.0.2.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/libmapnik.4.0.dylib"
  )

list(APPEND _cmake_import_check_targets mapnik::mapnik )
list(APPEND _cmake_import_check_files_for_mapnik::mapnik "${_IMPORT_PREFIX}/lib/libmapnik.4.0.2.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
